@@ -3,7 +3,7 @@ from importlib import util
 import matplotlib as mpl
 from pandas.plotting import register_matplotlib_converters
 
-from adcircpy.driver import AdcircRun
+from adcircpy.driver.driver import AdcircRun
 from adcircpy.forcing import Tides
 from adcircpy.mesh import AdcircMesh
 from adcircpy.fort15 import Fort15
@@ -20,5 +20,4 @@ register_matplotlib_converters()
 
 if util.find_spec("colored_traceback") is not None:
     import colored_traceback
-
     colored_traceback.add_hook(always=True)
