@@ -6,8 +6,8 @@ from adcircpy.forcing.base import Forcing
 
 class WaveForcing(Forcing, ABC):
     def __init__(self, nrs: int, interval_seconds: int):
+        super().__init__(interval_seconds)
         self.NRS = nrs
-        self.RSTIMINC = interval_seconds
 
     @abstractmethod
     def write(self, directory: PathLike, overwrite: bool = False):
