@@ -2,6 +2,7 @@
 # from adcircpy.outputs.ElevationStationsTimeseries \
 #     import ElevationStationsTimeseries
 from adcircpy.outputs.fort61 import ElevationStations, Fort61
+from adcircpy.outputs.fort63 import Fort63
 from adcircpy.outputs.maxele import Maxele
 
 # from AdcircPy.Outputs.HarmonicConstituentsElevationStations import \
@@ -12,6 +13,7 @@ __all__ = [
     # 'ElevationStationsTimeseries',
     'Maxele',
     'ElevationStations', 'Fort61',
+    'Fort63',
 
     # 'HarmonicConstituentsElevationStations'
 ]
